==> haskell-data-textual-0.3.0.2-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-9oLiqMyGSxW5QVkTt6yOdR
key: data-textual-0.3.0.2-9oLiqMyGSxW5QVkTt6yOdR
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Integral Data.Textual.Fractional
abi: 3915208fc1cf15a2afc16501f5c1180d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-9oLiqMyGSxW5QVkTt6yOdR
depends:
    base-4.9.1.0 bytestring-0.10.8.1
    parsers-0.12.6-JZPNrDNwBDK5gpig8teSpB
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    text-latin1-0.3-Hwsob6wyidH59Nt6fKYG22
    text-printer-0.5-GUjVFi9dz4eFhZWiAdkvhT
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.2-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-C1VdqP9hI4fFGUUKScV6pg
key: data-textual-0.3.0.2-C1VdqP9hI4fFGUUKScV6pg
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Integral Data.Textual.Fractional
abi: 652e7b4f016d1170323ff20906624152
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-C1VdqP9hI4fFGUUKScV6pg
depends:
    base-4.9.1.0 bytestring-0.10.8.1
    parsers-0.12.6-G0uu9qoRLz4HnH45wJLDZZ
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    text-latin1-0.3-Hwsob6wyidH59Nt6fKYG22
    text-printer-0.5-GUjVFi9dz4eFhZWiAdkvhT
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
